pub struct RaptorQEnvelope {
pub artifact_id: String,
pub artifact_type: String,
pub source_hash: String,
pub raptorq: RaptorQMetadata,
pub scrub: ScrubStatus,
pub decode_proofs: Vec<DecodeProof>,
}Fields
artifact_id: Stringartifact_type: Stringsource_hash: Stringraptorq: RaptorQMetadatascrub: ScrubStatusdecode_proofs: Vec<DecodeProof>Implementations
Sourceimpl RaptorQEnvelope
impl RaptorQEnvelope
pub fn from_source_bytes( artifact_id: impl Into<String>, artifact_type: impl Into<String>, source_bytes: &[u8], repair_symbols: u32, ) -> Self
Sourcepub fn push_decode_proof_capped(&mut self, proof: DecodeProof)
pub fn push_decode_proof_capped(&mut self, proof: DecodeProof)
Append a decode proof while enforcing a bounded history size.
When the cap is exceeded, oldest proofs are evicted first.